package com.nosum.deliver.author.controller;

import com.nosum.common.annotation.Explain;
import com.nosum.common.base.domain.PageInfo;
import com.nosum.common.base.domain.Result;
import com.nosum.deliver.author.domain.po.Author;
import com.nosum.deliver.author.service.AuthorService;
import org.bson.types.ObjectId;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.UUID;

/**
 * 作者信息接口层.
 *
 * @author 杜咏微
 */
@RestController
@RequestMapping("/admin/author")
public class AuthorAdminController {

    @Autowired
    private AuthorService authorService;

    @Explain("发起邀请")
    @PostMapping("/save")
    public Result<Void> save(@RequestBody Author author) {
        authorService.save(author);
        return Result.createWithSuccessMessage();
    }

    @GetMapping("/saveBatch")
    public Result<Void> saveBatch() {
        Result<Author> page = page(new Author());
        List<Author> models = page.getModels();
        Author author1 = models.get(0);
        for (int i = 0; i < 10; i++) {
            author1.setId(ObjectId.get());
            author1.setFinderUin(i + UUID.randomUUID().toString());
            save(author1);
        }

        return Result.createWithSuccessMessage();
    }

    @GetMapping("/{id}")
    public Result<Author> get(@PathVariable("id") ObjectId id) {
        return Result.createWithModel(authorService.getById(id));
    }


    @GetMapping("/finderUin/{finderUin}")
    public Result<Author> getByFinderUin(@PathVariable("finderUin") String finderUin) {
        return Result.createWithModel(authorService.getByFinderUin(finderUin));
    }


    @Explain("作者列表、投放列表分页查询")
    @GetMapping("/page")
    public Result<Author> page(Author author) {
        PageInfo<Author> pageInfo = authorService.getPage(PageInfo.withRequest(), author);
        return Result.createWithPaging(pageInfo.getRecord(), pageInfo);
    }


    @DeleteMapping("/{id}")
    public Result<Void> remove(@PathVariable("id") ObjectId id) {
        authorService.remove(id);
        return Result.createWithSuccessMessage();
    }

}
