package com.nosum.deliver.author.service.impl;

import cn.hutool.core.date.LocalDateTimeUtil;
import cn.hutool.core.util.StrUtil;
import com.nosum.common.base.domain.PageInfo;
import com.nosum.deliver.author.domain.po.Author;
import com.nosum.deliver.author.domain.po.AuthorVideo;
import com.nosum.deliver.author.service.AuthorService;
import com.nosum.deliver.author.service.AuthorVideoService;
import org.bson.types.ObjectId;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.mongodb.core.MongoTemplate;
import org.springframework.data.mongodb.core.query.Criteria;
import org.springframework.data.mongodb.core.query.Query;
import org.springframework.stereotype.Service;

import java.time.LocalDate;
import java.time.LocalDateTime;
import java.time.LocalTime;
import java.util.List;
import java.util.Objects;

/**
 * 作者信息服务层实现类.
 *
 * @author 杜咏微
 */
@Service
public class AuthorVideoServiceImpl implements AuthorVideoService {

    @Autowired
    private MongoTemplate mongoTemplate;

    @Override
    public void save(AuthorVideo authorVideo) {
        if (authorVideo.getStatus() == 1) {
            authorVideo.setPutTime(LocalDateTime.now());
        }
        mongoTemplate.save(authorVideo);
    }

    @Override
    public PageInfo<AuthorVideo> getPage(PageInfo<AuthorVideo> pageInfo, AuthorVideo authorVideo) {
        Criteria criteria = new Criteria();

        if (StrUtil.isNotBlank(authorVideo.getFinderUin())) {
            criteria.and("finderUin").is(authorVideo.getFinderUin());
        }

        if (Objects.nonNull(authorVideo.getStatus())) {
            criteria.and("status").is(authorVideo.getStatus());
        }

        if (authorVideo.getStartTime() != null && authorVideo.getStartTime() > 0
                && authorVideo.getEndTime() != null && authorVideo.getEndTime() > 0) {
            criteria.and("sendTime").gte(LocalDateTimeUtil.of(authorVideo.getStartTime())).lte(LocalDateTimeUtil.of(authorVideo.getEndTime()));
        }

        Query query = Query.query(criteria);
        query.skip((pageInfo.getPage() - 1) * pageInfo.getSize());
        query.limit((int) pageInfo.getSize());

        long total = mongoTemplate.count(query, AuthorVideo.class);
        if (total == 0) {
            return pageInfo;
        }
        List<AuthorVideo> authorVideos = mongoTemplate.find(query, AuthorVideo.class);
        authorVideos.forEach(obj -> {
            obj.setAuthor(mongoTemplate.findOne(Query.query(Criteria.where("finderUin").is(obj.getFinderUin())), Author.class));
            obj.setSendTimeStr(LocalDateTimeUtil.formatNormal(obj.getSendTime()));
            obj.setPutTimeStr(LocalDateTimeUtil.formatNormal(obj.getPutTime()));
        });
        return pageInfo.setRecord(authorVideos).setTotal(total);
    }

    @Override
    public AuthorVideo getById(ObjectId id) {
        return mongoTemplate.findById(id, AuthorVideo.class);
    }

    @Override
    public void remove(ObjectId id) {
        mongoTemplate.remove(Query.query(Criteria.where("id").is(id)), AuthorVideo.class);
    }
}
